import os
import platform

def set_environment_variable(key, value):
    os_name = platform.system()
    os.environ[key] = value
    # Save the environment variable permanently
    if (os_name == "Windows"):
        import winreg
        with winreg.OpenKey(winreg.HKEY_CURRENT_USER, "Environment", 0, winreg.KEY_ALL_ACCESS) as reg_key:
            winreg.SetValueEx(reg_key, key, 0, winreg.REG_SZ, value)
    else:
        os.system("bash")


import requests
import os
import subprocess

def with_request(gist, headers):
    gist_id = gist["id"]
    if not os.path.exists(gist_id):
        os.mkdir(gist_id)
    files = gist["files"]
    for filename in files:
        gist_url = files[filename]["raw_url"]
        response = requests.get(gist_url, headers=headers)
        with open(f"{gist_id}/{filename}", "wb") as file:
            file.write(response.content)

def with_git(gist):
    if not os.path.exists(gist["id"]):
        subprocess.call(["git", "clone", gist["git_pull_url"]])
    else:
        subprocess.call(["git", "pull", gist["git_pull_url"]])

def download_gists(username, token, git_check):
    API_ENDPOINT = f"https://api.github.com/users/{username}/gists"
    
    headers = {
        "Authorization": f"token {token}",
    }

    if not token:
        headers = None
    
    response = requests.get(API_ENDPOINT, headers=headers)

    if response.status_code == 200:
        for gist in response.json():
            with_request(gist, headers) if not git_check else with_git(gist)
    else:
        print(response.status_code, response.text)


from .download import download_gists
from .environment import set_environment_variable
import argparse
import os

def main():
    parser = argparse.ArgumentParser(description="Download specified user's all gists at once")
    parser.add_argument("-u", "--username", type=str, metavar="Username", help="Github username to download gists from.")
    parser.add_argument("-t", "--token", type=str, metavar="Token", help="Github public access token if you want to also download private gists.")
    parser.add_argument("-e", "--environment", action="store_true", help="Whether to use environment variables or not.")
    parser.add_argument("-g", "--git", action="store_true", help="Whether to download with git or not. False by default since it's dependent on whether or not git is downloaded (and your ssh/gpg key). IF YOU TYPE ANYTHING IN AFTER -g/--git IT WILL BE ACCEPTED AS TRUE.")
    parser.add_argument("-gu", "--gusername", type=str, metavar="Username", help="Set Github username as environment variable.")
    parser.add_argument("-gpat", "--gpat", type=str, metavar="Token", help="Set Github personal access token as environment variable.")
    
    args = parser.parse_args()
    
    if (args.gusername):
        set_environment_variable("GITHUB_USERNAME", args.gusername)
    if (args.gpat):
        set_environment_variable("GITHUB_PERSONAL_ACCESS_TOKEN", args.gpat)
    if (not args.gusername and not args.gpat):
        if args.environment: # false by default/if you don't use the argument
            username = os.getenv("GITHUB_USERNAME")
            token = os.getenv("GITHUB_PERSONAL_ACCESS_TOKEN")
        else:
            username = args.username
            token = args.token
        
        git_check = args.git # false by default/if you don't use the argument
        
        if (not username):
            print("Pass your Github username with -u.")
        else:
            download_gists(username, token, git_check)
    
if __name__ == "__main__":
    main()


from setuptools import setup, find_packages

VERSION = "1.5"
DESCRIPTION = "CLI for downloading all gists from a specified user."
LONG_DESCRIPTION = "Download specified user's all gists at once.\nYou can also use environment variables if you don't want to pass through arguments everytime you want to download a gist.\nIf you don't provide a public access token it will only download public gists.\nFor more information check out: https://github.com/NecRaul/gist-neko/"
AUTHOR = "NecRaul"

setup(
    name="gist_neko",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author=AUTHOR,
    packages=find_packages(),
    install_requires=["requests"],
    keywords=["python", "gists downloader", "downloader", "gists", "gist-neko", "kuroneko"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Internet :: WWW/HTTP"
    ],
    py_modules=["download", "environment"],
    entry_points={
        "console_scripts": [
            "gist-neko = gist_neko.__init__:main",
        ],
    },
)